@@ -76,7 +76,9 @@ HostList::operator=( const HostList& other )
 	IPMSG_FUNC_ENTER( "HostList& HostList::operator=( const HostList& other )" );
 	IpMsgMutexInit( "HostList::operator=(HostList&)", &hostListMutex, NULL );
 	Lock( "HostList::operator=(HostList&)" );
+	other.Lock( "HostList::operator=(HostList&)" );
 	CopyFrom( other );
+	other.Unlock( "HostList::operator=(HostList&)" );
 	Unlock( "HostList::operator=(HostList&)" );
 	IPMSG_FUNC_RETURN( *this );
 }
@@ -246,6 +248,7 @@ HostList::AddHost( const HostListItem& host, bool isPermitSameHardwareAddress )
 	//ƬΥåȥɥ쥹եߥNICõץ饤ޥ(ɥ쥹)Ȥư١θõΥǥå롣
 	int nicStartIndex = 1;
 	if ( !agent->haveIPv4Nic && !agent->haveIPv6Nic ) {
+			Unlock( "HostList::AddHost()" );
 			IPMSG_FUNC_RETURN( 0 );
 	} else if ( agent->haveIPv4Nic && agent->haveIPv6Nic && host.AddressFamily() == AF_INET6 ) {
 		//IPv4,IPv6ξȤʤIPv6ͥ衣
@@ -405,11 +408,14 @@ HostList::AddHost( const HostListItem& host, bool isPermitSameHardwareAddress )
 		ret = 1;
 	} else {
 #if defined(INFO) || !defined(NDEBUG)
-		printf("HostList::AddHost Host(%s[%s]) was not found.Nickname=[%s] GroupName=[%s]\n",
+		printf("HostList::AddHost Host(%s[%s]) was found,Not added. Nickname=[%s] GroupName=[%s]\n",
 					host.IpAddress().c_str(), host.HardwareAddress().c_str(), host.Nickname().c_str(), host.GroupName().c_str() );
 		fflush(stdout);
 #endif
 	}
+#if defined(INFO) || !defined(NDEBUG)
+	IpMsgDumpHost( "HostList::AddList", host );
+#endif
 	if ( agent->GetSortHostListComparator() != NULL ){
 		if ( items.size() > 0 ) {
 			qsort( agent->GetSortHostListComparator(), 0, items.size() - 1 );
@@ -443,11 +449,13 @@ HostList::DeleteHostByAddress( std::string addr )
 	Lock( "HostList::DeleteHostIpAddress()" );
 	struct sockaddr_storage ss;
 	if ( createSockAddrIn( &ss, addr, 0 ) == NULL ){
+		Unlock( "HostList::DeleteHostByAddress()" );
 		IPMSG_FUNC_EXIT;
 	}
 	for( std::vector<HostListItem>::iterator ix = items.begin(); ix < items.end(); ix++ ){
 		struct sockaddr_storage ixss;
 		if ( createSockAddrIn( &ixss, ix->IpAddress(), 0 ) == NULL ){
+			Unlock( "HostList::DeleteHostByAddress()" );
 			IPMSG_FUNC_EXIT;
 		}
 		if ( isSameSockAddrIn( ss, ixss ) ){
@@ -568,9 +576,18 @@ HostList::FindHostByHostName( std::string hostName, int addressFamily )
 	Lock( "HostList::FindHostByHostName()" );
 	std::vector<HostListItem>::iterator ret = end();
 
+#if defined(INFO) || !defined(NDEBUG)
+	printf("FindHostByName->%s(%d)\n",hostName.c_str(), addressFamily );
+#endif
 	for( std::vector<HostListItem>::iterator ix = begin(); ix < end(); ix++ ){
+#if defined(INFO) || !defined(NDEBUG)
+		printf("(FindHostByName->%s(%d))\n",ix->HostName().c_str(), ix->AddressFamily() );
+#endif
 		if ( ix->HostName() == hostName && addressFamily == ix->AddressFamily() ) {
 			ret = ix;
+#if defined(INFO) || !defined(NDEBUG)
+			printf("FindHostByName found.\n" );
+#endif
 			break;
 		}
 	}
@@ -591,14 +608,25 @@ HostList::FindHostByAddress( std::string addr )
 	std::vector<HostListItem>::iterator ret = end();
 	struct sockaddr_storage ss;
 	if ( createSockAddrIn( &ss, addr, 0 ) == NULL ){
+		Unlock( "HostList::FindHostByAddress()" );
 		IPMSG_FUNC_RETURN( ret );
 	}
+#if defined(INFO) || !defined(NDEBUG)
+	printf("FindHostByAddress->%s\n",addr.c_str());
+#endif
 	for( std::vector<HostListItem>::iterator ix = begin(); ix < end(); ix++ ){
 		struct sockaddr_storage ixss;
 		if ( createSockAddrIn( &ixss, ix->IpAddress(), 0 ) == NULL ){
+			Unlock( "HostList::FindHostByAddress()" );
 			IPMSG_FUNC_RETURN( ret );
 		}
+#if defined(INFO) || !defined(NDEBUG)
+		printf("FindHostByAddress->%s(%s)\n",ix->HostName().c_str(),ix->IpAddress().c_str());
+#endif
 		if ( isSameSockAddrIn( ss, ixss ) ){
+#if defined(INFO) || !defined(NDEBUG)
+			printf("FindHostByAddress found.\n" );
+#endif
 			ret = ix;
 			break;
 		}
